results_kmean_aug: Example dataset The Augmented KMeans Results

results_kmean_augR Documentation

Example dataset The Augmented KMeans Results

Description

Data from Predicting the clinical status of human breast cancer by using gene expression profiles

Usage

data(results_kmean_aug)

Format

A dataframe

https://github.com/ramhiser/datamicroarray/blob/master/data/west.RData

References

Predicting the clinical status of human breast cancer by using gene expression profiles DOI: 10.1073/pnas.201162998

Examples

data(results_kmean_aug)

rforbiodatascience22/Twenty documentation built on May 13, 2022, 8:14 p.m.