Example dataset PCA Eigenvalues
results_pca_eig.RdData from Predicting the clinical status of human breast cancer by using gene expression profiles
Usage
data(results_pca_eig)References
Predicting the clinical status of human breast cancer by using gene expression profiles DOI: 10.1073/pnas.201162998
Examples
data(results_pca_eig)
#> Warning: data set ‘results_pca_eig’ not found