west_data_wide: Example dataset west_data_wide A wide dataset

west_data_wideR Documentation

Example dataset west_data_wide A wide dataset

Description

Data from Predicting the clinical status of human breast cancer by using gene expression profiles

Usage

data(west_data_wide)

Format

A dataframe

https://github.com/ramhiser/datamicroarray/blob/master/data/west.RData

References

Predicting the clinical status of human breast cancer by using gene expression profiles DOI: 10.1073/pnas.201162998

Examples

data(west_data_wide)

rforbiodatascience22/Twenty documentation built on May 13, 2022, 8:14 p.m.